<?php

declare(strict_types=1);

namespace Drupal\reviewer_test\Plugin\reviewer\Checklist;

use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\reviewer\Attribute\Checklist;
use Drupal\reviewer\Plugin\reviewer\Checklist\ChecklistBase;

/**
 * Test entity displays checklist.
 */
#[Checklist(
  id: 'entity_display_tests',
  label: 'Entity Display Tests',
)]
class EntityDisplayTest extends ChecklistBase {

  /**
   * {@inheritdoc}
   */
  public function tasks(): array {
    return [
      $this->taskFactory->create('label_visible', $this->labelHidden(...), 'Visible field labels for fields: @failures.'),
    ];
  }

  /**
   * Test that field labels are hidden.
   *
   * @param array<string, \Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\ImmutableConfig> $configuration
   *
   * @return array<string, bool>|bool
   */
  private function labelHidden(array $configuration): array|bool {
    $results = [];
    foreach ($configuration as $config) {
      if ($config instanceof EntityViewDisplayInterface) {
        foreach ($config->getComponents() as $field => $settings) {
          if (isset($settings['label'])) {
            $results["{$config->getMode()}.$field"] = $settings['label'] === 'hidden';
          }
        }
      }
    }
    return $results ?: TRUE;
  }

}
