<?php

declare(strict_types=1);

namespace Drupal\reviewer_test\Plugin\reviewer\Checklist;

use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\reviewer\Attribute\Checklist;
use Drupal\reviewer\Plugin\reviewer\Checklist\ChecklistBase;

/**
 * Test links checklist.
 */
#[Checklist(
  id: 'link_display_tests',
  label: 'Link Display Tests',
)]
class LinksDisplayChecklist extends ChecklistBase {

  /**
   * {@inheritdoc}
   */
  public function tasks(): array {
    return [
      $this->taskFactory->create('link_trimmed', $this->linkNotTrimmed(...), 'Link text output is trimmed on the following fields: @failures'),
    ];
  }

  /**
   * Test that link text is not trimmed.
   *
   * @param array<string, \Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\ImmutableConfig> $configuration
   *
   * @return array<string, bool>|bool
   */
  private function linkNotTrimmed(array $configuration): array|bool {
    $results = [];
    foreach ($configuration as $config) {
      if ($config instanceof EntityViewDisplayInterface) {
        foreach ($config->getComponents() as $field => $settings) {
          if (isset($settings['type']) && $settings['type'] === 'link') {
            $results[$field] = $settings['settings']['trim_length'] === NULL;
          }
        }
      }
    }
    return $results ?: TRUE;
  }

}
