<?php

declare(strict_types=1);

namespace Drupal\reviewer_test\Plugin\reviewer\Checklist;

use Drupal\Core\Config\ImmutableConfig;
use Drupal\reviewer\Attribute\Checklist;
use Drupal\reviewer\Plugin\reviewer\Checklist\ChecklistBase;

/**
 * Test site settings checklist.
 */
#[Checklist(
  id: 'site_configuration_tests',
  label: 'Site Configuration Tests',
)]
class SiteConfigurationTests extends ChecklistBase {

  /**
   * {@inheritdoc}
   */
  public function tasks(): array {
    return [
      $this->taskFactory->create('slogan', $this->slogan(...), 'Site slogan not set.'),
      $this->taskFactory->create('cache_max_age', $this->cacheMaxAge(...), 'Cache max age set to 0.'),
    ];
  }

  /**
   * Test that the site slogan is set.
   *
   * @param array<string, \Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\ImmutableConfig> $configuration
   */
  private function slogan(array $configuration): bool {
    $config = $configuration['system.site'];
    assert($config instanceof ImmutableConfig);
    return $config->get('slogan') !== '';
  }

  /**
   * Test that the site slogan is set.
   *
   * @param array<string, \Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\ImmutableConfig> $configuration
   */
  private function cacheMaxAge(array $configuration): bool {
    $config = $configuration['system.performance'];
    assert($config instanceof ImmutableConfig);
    return $config->get('cache.page.max_age') !== 0;
  }

}
